@@ -273,6 +273,11 @@ test_that("chop_equally", {
     chop_equally(x, 2, labels = lbl_intervals(raw = TRUE)),
     chop_equally(x, 2, raw = TRUE)
   )
+
+  expect_warning(
+    chop_equally(c(1, 1, 2, 2), 4),
+    "Fewer"
+  )
 })
 
 
@@ -297,6 +302,13 @@ test_that("chop_n", {
 })
 
 
+test_that("Bugfix: chop_n(tail = 'merge') works with n > length(x)", {
+  expect_silent(
+    chop_n(1:3, 4, tail = "merge", extend = FALSE)
+  )
+})
+
+
 test_that("chop_mean_sd", {
   x <- -1:1 # mean 0, sd 1
   expect_silent(res <- chop_mean_sd(x))
